@@ -95,20 +95,18 @@ typedef struct _SetFrameData SetFrameData;
 static GtkHTMLEditorAPI *editor_api;
 
 static void
-activate_ui_cb (BonoboControl      *control,
+activate_cb (BonoboControl      *control,
 	     gboolean            active,
 	     GtkHTMLControlData *cd)
 {
+	Bonobo_UIContainer remote_ui_container;
 	BonoboUIComponent *ui_component;
 
-	ui_component = bonobo_control_get_ui_component (control);
+	printf ("ACTIVATE\n");
 
 	if (active) {
-		Bonobo_UIContainer remote_ui_container;
-
-		cd->uic = ui_component;
-
 		remote_ui_container = bonobo_control_get_remote_ui_container (control, NULL);
+		cd->uic = ui_component = bonobo_control_get_ui_component (control);
 		bonobo_ui_component_set_container (ui_component, remote_ui_container, NULL);
 		bonobo_object_release_unref (remote_ui_container, NULL);
 
@@ -120,6 +118,8 @@ static void
 set_frame_cb (BonoboControl *control,
 	      gpointer data)
 {
+	Bonobo_UIContainer remote_ui_container;
+	BonoboUIComponent *ui_component;
 	GtkHTMLControlData *control_data;
 	GtkWidget *toolbar;
 	GtkWidget *scrolled_window;
@@ -133,7 +133,9 @@ set_frame_cb (BonoboControl *control,
 
 	CORBA_Object_release (frame, NULL);
 
-	control_data->uic = bonobo_control_get_ui_component (control);
+	remote_ui_container = bonobo_control_get_remote_ui_container (control, NULL);
+	control_data->uic = ui_component = bonobo_control_get_ui_component (control);
+	bonobo_ui_component_set_container (ui_component, remote_ui_container, NULL);
 
 	/* Setup the tool bar.  */
 
@@ -148,10 +150,19 @@ set_frame_cb (BonoboControl *control,
 
 	gtk_box_pack_start (GTK_BOX (control_data->vbox), scrolled_window, TRUE, TRUE, 0);
 
-	/* hack to setup the bonobo ui if activate isn't working */
-	activate_ui_cb (control, TRUE, control_data);
+	/* Setup the menu bar.  */
+
+	menubar_setup (ui_component, control_data);
+
+	if (!spell_has_control ()) {
+		control_data->has_spell_control = FALSE;
+		bonobo_ui_component_set_prop (ui_component, "/commands/EditSpellCheck", "sensitive", "0", NULL);
+	} else
+		control_data->has_spell_control = TRUE;
 
 	gtk_html_set_editor_api (GTK_HTML (control_data->html), editor_api, control_data);
+
+	bonobo_object_release_unref (remote_ui_container, NULL);
 }
 
 static gint
@@ -240,17 +251,12 @@ load_from_file (GtkHTML *html,
 	unsigned char buffer[4096];
 	int len;
 	int fd;
-        char *path;
+        const char *path;
 
         if (strncmp (url, "file:", 5) == 0)
-		path = g_filename_from_uri(url, NULL, NULL);
-	else
-		path = g_strdup(url);
+		path = url + 5; 
 
-	fd = open (path, O_RDONLY);
-	g_free(path);
-
-	if (fd == -1) {
+	if ((fd = open (path, O_RDONLY)) == -1) {
 		g_warning ("%s", g_strerror (errno));
 		return FALSE;
 	}
@@ -626,7 +632,7 @@ editor_control_construct (BonoboControl *control, GtkWidget *vbox)
 	   embedded in its control frame.  We use the "set_frame" signal to
 	   handle that.  */
 
-	/* g_signal_connect (control, "activate", G_CALLBACK (activate_ui_cb), cd); */
+	g_signal_connect (control, "activate", G_CALLBACK (activate_cb), cd);
 	g_signal_connect (control, "set_frame", G_CALLBACK (set_frame_cb), cd);
 	g_signal_connect (html_widget, "url_requested", G_CALLBACK (url_requested_cb), cd);
 	g_signal_connect (html_widget, "button_press_event", G_CALLBACK (html_button_pressed), cd);
