@@ -51,9 +51,7 @@
 #include "htmltextarea.h"
 #include "htmltextinput.h"
 #include "htmltextslave.h"
-#include "htmlvspace.h"
 
-
 /* This is used to statically initialize all the classes we are using.  */
 
 static gboolean types_inited = FALSE;
@@ -91,7 +89,6 @@ html_types_init (void)
 	html_image_type_init ();
 	html_imageinput_type_init ();
 	html_link_text_type_init ();
-	html_map_type_init ();
 	html_object_type_init ();
 	html_radio_type_init ();
 	html_rule_type_init ();
@@ -102,7 +99,6 @@ html_types_init (void)
 	html_text_input_type_init ();
 	html_text_slave_type_init ();
 	html_text_type_init ();
-	html_vspace_type_init ();
 
 	html_frameset_type_init ();
 	html_frame_type_init ();
@@ -151,8 +147,6 @@ html_type_name (HTMLType type)
  		return "ImageInput";
 	case HTML_TYPE_LINKTEXT:
  		return "LinkText";
-	case HTML_TYPE_MAP:
- 		return "Map";
 	case HTML_TYPE_OBJECT:
  		return "Object";
 	case HTML_TYPE_RADIO:
